@@ -169,7 +169,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.28'
+__version__ = '0.1.29'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -342,18 +342,20 @@ class LiszDataMixin(ABC):
         want_node = 'node' in nid
         err_msg = self.edit_validate(-1, item_id, want_node=want_node,
                                      parent_node=node_to_add_to, new_item_index=new_item_index)
-        if want_node:
-            if err_msg:
-                item_idx = self.find_item_index(item_id, searched_node=node_to_add_to)
-                if item_idx >= 0:                                   # found the blocking/duplicate item id
-                    if 'node' not in node_to_add_to[item_idx]:
-                        node_to_add_to[item_idx]['node'] = list()   # convert blocking item from leaf to node
-                    err_msg = ("(ignorable) " + err_msg) if self.debug_level else ""
-                    sub_err = self.add_items(nid['node'], node_to_add_to=node_to_add_to[item_idx]['node'])
-                    if sub_err:                                     # add (ignorable?) errors from sub-node adds
-                        err_msg += "\n" + sub_err
-            else:
-                node_to_add_to[new_item_index]['node'].extend(nid['node'])
+        if not err_msg:
+            # overwrite inserted nid because edit_validate(used for to ensure proper id and no dup) creates new nid
+            node_to_add_to[new_item_index] = nid
+
+        elif want_node:
+            # if want node then first check if error is dup error and fixable
+            item_idx = self.find_item_index(item_id, searched_node=node_to_add_to)
+            if item_idx >= 0:                                   # found the blocking/duplicate item id
+                if 'node' not in node_to_add_to[item_idx]:
+                    node_to_add_to[item_idx]['node'] = list()   # convert blocking item from leaf to node
+                err_msg = ("(ignorable) " + err_msg) if self.debug_level else ""
+                sub_err = self.add_items(nid['node'], node_to_add_to=node_to_add_to[item_idx]['node'])
+                if sub_err:                                     # add (ignorable?) errors from sub-node adds
+                    err_msg += "\n" + sub_err
 
         return err_msg
 
@@ -560,25 +562,31 @@ class LiszDataMixin(ABC):
                 node = path_nid['node']         # type: ignore   # mypy not supports recursive types see issue #731
         return flow_path
 
-    def flow_path_node(self, flow_path: List[str] = None, strict: bool = False) -> LiszNode:
+    def flow_path_node(self, flow_path: List[str] = None, create: bool = False) -> LiszNode:
         """ determine the node specified by the passed flow path.
 
         :param flow_path:       flow path list.
-        :param strict:          pass True to return empty list on invalid/broken flow_path.
-        :return:                node list.
+        :param create:          pass True to create missing nodes.
+                                Only on False this method will return empty list on invalid/broken flow_path.
+        :return:                node list at flow_path (if found -or- created is True and no-creation-errors)
+                                or empty list (if flow_path not found and created is False or on creation error).
         """
         if flow_path is None:
             flow_path = self.flow_path
+
         node = self.root_node
+
         for flow_id in flow_path:
             if flow_action(flow_id) == 'enter':
                 node_id = flow_key(flow_id)
                 item = self.item_by_id(node_id, searched_node=node)
-                if 'node' not in item:
-                    if strict:
-                        node = list()
-                    break                           # actually not needed, will repair broken flow path
+                if item not in node or 'node' not in item:
+                    if not create or item not in node and self.add_item(item, node_to_add_to=node):
+                        return list()           # on error RETURN empty list
+                    if 'node' not in item:
+                        item['node'] = list()
                 node = item['node']
+
         return node
 
     def flow_path_quick_jump_nodes(self) -> List[str]:
@@ -751,14 +759,14 @@ class LiszDataMixin(ABC):
 
         :param item_id:         item id to find.
         :param searched_node:   searched node. if not passed then the current node will be searched instead.
-        :return:                found item or empty dict with new/empty id if not found.
+        :return:                found item or if not found a new dict with the single key=value 'id'=item_id.
         """
         if searched_node is None:
             searched_node = self.current_node_items
         index = self.find_item_index(item_id, searched_node=searched_node)
         if index != -1:
             return searched_node[index]
-        return dict(id='')
+        return dict(id=item_id)
 
     def move_item(self, dragged_node: LiszNode, dragged_id: str,
                   dropped_path: Optional[List[str]] = None, dropped_id: str = '') -> bool:
